@@ -21,6 +21,7 @@ import pango
 from gettext import gettext as _
 from gnomedvb import seconds_to_time_duration_string
 from gnomedvb.ui.widgets.ScheduleStore import ScheduleStore
+from gnomedvb.ui.widgets.CellRendererDatetime import CellRendererDatetime
 
 class ScheduleView(gtk.TreeView):
 
@@ -32,16 +33,19 @@ class ScheduleView(gtk.TreeView):
         
         self.prev_selection = None
         self.set_property("headers-visible", False)
-        self.get_selection().connect("changed", self._on_selection_changed)
-        
+
+        col_time = gtk.TreeViewColumn("Time")
+
         cell_rec = gtk.CellRendererPixbuf()
-        col_rec = gtk.TreeViewColumn("Recording", cell_rec)
-        col_rec.set_cell_data_func(cell_rec, self._get_rec_data)
-        self.append_column(col_rec)
-        
-        cell_time = gtk.CellRendererText()
-        col_time = gtk.TreeViewColumn("Time", cell_time)
+        col_time.pack_start(cell_rec, expand=False)
+        col_time.set_cell_data_func(cell_rec, self._get_rec_data)
+
+        cell_time = CellRendererDatetime()
+        col_time.pack_start(cell_time)
         col_time.set_cell_data_func(cell_time, self._get_time_data)
+        col_time.set_attributes(cell_time, datetime=ScheduleStore.COL_DATETIME,
+            format=ScheduleStore.COL_FORMAT)
+
         self.append_column(col_time)
         
         cell_description = gtk.CellRendererText()
@@ -55,7 +59,7 @@ class ScheduleView(gtk.TreeView):
         event_id = model[aiter][ScheduleStore.COL_EVENT_ID]
 
         if event_id == ScheduleStore.NEW_DAY:
-            date = model.get_datetime(aiter)
+            date = model[aiter][ScheduleStore.COL_DATETIME]
             description = "<big><b>%s</b></big>" % date.strftime("%A %x")
             cell.set_property("xalign", 0.5)
             cell.set_property ("cell-background-gdk", self.style.bg[gtk.STATE_NORMAL])
@@ -71,15 +75,6 @@ class ScheduleView(gtk.TreeView):
                 short_desc += "\n"
             
             description = "<b>%s</b>\n%s<small><i>%s: %s</i></small>" % (title, short_desc, _("Duration"), duration)
-            
-            # Check if row is the selected row
-            sel_iter = self.get_selection().get_selected()[1]
-            if sel_iter != None and model.get_path(aiter) == model.get_path(sel_iter):
-                ext_desc = model[aiter][ScheduleStore.COL_EXTENDED_DESC]
-                if ext_desc == None:
-                    ext_desc = model.get_extended_description(aiter)
-                    model[aiter][ScheduleStore.COL_EXTENDED_DESC] = ext_desc
-                description += "\n<small>%s</small>" % ext_desc
         
         cell.set_property("markup", description)
         
@@ -87,11 +82,8 @@ class ScheduleView(gtk.TreeView):
         event_id = model[aiter][ScheduleStore.COL_EVENT_ID]
         
         if event_id == ScheduleStore.NEW_DAY:
-            cell.set_property("text", "")
             cell.set_property ("cell-background-gdk", self.style.bg[gtk.STATE_NORMAL])
         else:
-            date = model.get_datetime(aiter)
-            cell.set_property("text", date.strftime("%X"))
             cell.set_property ("cell-background-gdk", self.style.base[gtk.STATE_NORMAL])
             
     def _get_rec_data(self, column, cell, model, aiter):
@@ -107,12 +99,3 @@ class ScheduleView(gtk.TreeView):
         else:
             cell.set_property("icon-name", None)
 
-    def _on_selection_changed(self, selection):
-        model, aiter = selection.get_selected()
-        # Update cell height of previously and currenlty selected row
-        if self.prev_selection != None:
-            model.emit ("row-changed", model.get_path(self.prev_selection), self.prev_selection)
-        if aiter != None:
-            model.emit ("row-changed", model.get_path(aiter), aiter)
-        self.prev_selection = aiter
-
